package com.engine.htsc.duban.service.impl;

import com.engine.core.impl.Service;
import com.engine.htsc.duban.cmd.*;
import com.engine.htsc.duban.service.DubanService;
import weaver.conn.RecordSet;
import weaver.general.Util;
import weaver.hrm.User;
import java.util.HashMap;
import java.util.Map;

public class DubanServiceImpl extends Service implements DubanService {

    @Override
    public Map<String, Object> createTask(Map<String, Object> params, User user) {
        return commandExecutor.execute(new CreateTaskCmd(params,user));
    }

    @Override
    public Map<String, Object> createSubTask(Map<String, Object> params, User user) {
        return commandExecutor.execute(new CreateSubTaskCmd(params,user));
    }

    @Override
    public Map<String, Object> getDataList(Map<String, Object> params, User use) {
        return commandExecutor.execute(new DbrwFkCmd(params,user));
    }

    @Override
    public Map<String, Object> getreportList(Map<String, Object> params, User user) {
        return commandExecutor.execute(new CoworkReportCmd(params,user));
    }

    @Override
    public Map<String, Object> getdynamicsList(Map<String, Object> params, User user) {
        return commandExecutor.execute(new DynamicsReportCmd(params,user));
    }

    @Override
    public Map<String, Object> dbxzDelete(Map<String, Object> params, User user) {
        return commandExecutor.execute(new DbsxDeleteCmd(params,user));
    }

    @Override
    public Map<String, Object> doGetDbComplete(Map<String, Object> params, User user) {
        return commandExecutor.execute(new CoDbWorkCmd(params,user));
    }

    @Override
    public Map<String, Object> doGetTopButton(Map<String, Object> params, User user) {
        return commandExecutor.execute(new DubanTopButtonCmd(params,user));
    }

}
