package com.engine.htsc.duban.service;

import com.alibaba.fastjson.JSONObject;
import weaver.hrm.User;

import java.util.Map;

public interface DubanService {

    /**
     *
     * @param params
     * @return
     */
    Map<String,Object> createTask(Map<String, Object> params, User user);

    /**
     *
     * @param params
     * @param user
     * @return
     */
    Map<String,Object> createSubTask(Map<String, Object> params, User user);


    /***
     *
     * @param params
     * @param user
     * @return
     */
    Map<String, Object> getDataList(Map<String,Object> params,User user);

    /**
     *
     * @param user
     * @return
     */
    Map<String,Object> getreportList(Map<String,Object> params,User user);

    /**
     *
     * @param user
     * @return
     */
    Map<String,Object> getdynamicsList(Map<String,Object> params,User user);

    /***
     *
     * @param params
     * @param user
     * @return
     */
    Map<String,Object> dbxzDelete(Map<String, Object> params, User user);


    /**
     *
     * @param user
     * @return
     */
    Map<String,Object> doGetDbComplete(Map<String, Object> params, User user);


    /**
     *
     * @param user
     * @return
     */
    Map<String,Object> doGetTopButton(Map<String, Object> params, User user);

}
